<?php

namespace App\Http\Controllers;

use App\Models\Citas;
use App\Models\Cliente;
use Illuminate\Http\Request;

class ControllerCitas extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = Citas::with('cliente')->orderBy('fecha')->orderBy('hora')->get();
        return view('cita.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $data = Cliente::all();
    
        $horas = [];
        for ($hora = 8; $hora <= 20; $hora++) {
            $hourFormatted = \Carbon\Carbon::createFromFormat('H', $hora)->format('h:i A');
            $hour24 = \Carbon\Carbon::createFromFormat('H', $hora)->format('H:i');
            $horas[$hour24] = $hourFormatted;
        }
    
        return view('cita.create', compact('data', 'horas'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'id_cliente' => 'required|exists:clientes,id_cliente',
            'fecha' => 'required|date',
            'hora' => 'required|date_format:H:i',
        ]);
    
        $citaExistente = Citas::where('fecha', $request->fecha)->where('hora', $request->hora)->first();
    
        $confirmacion = [
            'fecha' => $request->fecha,
            'hora' => $request->hora,
            'existente' => $citaExistente ? true : false
        ];
    
        if ($citaExistente) {
            return redirect()->route('resultado')->with('confirmacion', $confirmacion);
        }
    
        $cita = new Citas();
        $cita->id_cliente = $request->id_cliente;
        $cita->fecha = $request->fecha;
        $cita->hora = $request->hora;
        $cita->save();
    
        return redirect()->route('resultado')->with('confirmacion', $confirmacion);
    }
    
    


    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $item = Citas::find($id);
        $item->delete();

        return back();
    }

    public function resultado()
    {
        return view('cita.resultado');
    }

    public function citasAtendidas(){
        $data = Citas::with('cliente')->orderBy('fecha')->orderBy('hora')->get();
        return view('cita.citasAtendidas', compact('data'));
    }

    public function citasProximas(){
        $data = Citas::with('cliente')->orderBy('fecha')->orderBy('hora')->get();
        return view('cita.citasProximas', compact('data'));
    }

    public function marcarAtendida(string $id)
    {
        $cita = Citas::find($id);
        $cita->atendida = true;
        $cita->save();
    
        return back();
    }
}
