<?php

namespace App\Http\Controllers;

use App\Models\Citas;
use App\Models\Cliente;
use Illuminate\Http\Request;

class ControllerClientes extends Controller
{
     /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = Cliente::all(); 
        return view('cliente.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('cliente.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'nombre' => 'required|string|max:200',
            'telefono' => 'nullable|string|max:20',
            'correo' => 'nullable|email|max:50',
        ]);

        $cliente = new Cliente();
        $cliente->nombre = $request->nombre;
        $cliente->telefono = $request->telefono;
        $cliente->correo = $request->correo;


        $cliente->save();

        return redirect()->route('clientes.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $data = Cliente::with(['citas' => function ($query) {
            $query->orderBy('atendida')->orderBy('fecha')->orderBy('hora');
        }])->find($id);

        return view('cliente.show', compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $item = Cliente::find($id);
        return view('cliente.update', compact('item'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {

        $cliente = Cliente::find($id);
        $cliente->nombre = $request->nombre;
        $cliente->telefono = $request->telefono;
        $cliente->correo = $request->correo;



        $cliente->save();

        return redirect()->route('clientes.index');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $item = Cliente::find($id);
        $item->delete();

        return back();
    }
}
